# This file describes data-plane and management-plane library tests, which can differ slightly.
# Test requirements are documented at https://github.com/Azure/azure-sdk-for-python/blob/main/doc/dev/tests.md.
# SDK tests should use `pytest`, and tests that send service requests should be recorded with the Azure SDK test proxy.

from devtools_testutils import AzureRecordedTestCase, AzureMgmtRecordedTestCase
from azure.template import template_main


# The `devtools_testutils` package in the SDK repository provides test capabilities.
# `AzureRecordedTestCase` provides methods for client creation, resource naming, and more.
# Tools from `devtools_testutils` are not required; plain `pytest` unit tests can be sufficient in some scenarios.
class TestDataPlane(AzureRecordedTestCase):
    def setup_method(self, method):
        # Code in this optional method will be executed before each test in the class runs.
        # Fixtures can also perform test-specific setup: https://docs.pytest.org/latest/explanation/fixtures.html
        pass

    def test_case_default(self):
        assert template_main() == True


# `AzureMgmtRecordedTestCase` inherits from `AzureRecordedTestCase` and also includes a `create_mgmt_client` method.
# This class should only be used by management-plane libraries in most cases. `azure-mgmt-*` libraries have their own
# reference material for testing: https://github.com/Azure/azure-sdk-for-python/blob/main/doc/dev/mgmt/tests.md.
class TestMgmtPlane(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        pass

    def test_case_default(self):
        assert template_main() == True



#!/usr/bin/env python

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

from setuptools import setup, find_packages
import os
from io import open
import re

# example setup.py Feel free to copy the entire "azure-template" folder into a package folder named
# with "azure-<yourpackagename>". Ensure that the below arguments to setup() are updated to reflect
# your package.

# this setup.py is set up in a specific way to keep the azure* and azure-mgmt-* namespaces WORKING all the way
# up from python 2.7. Reference here: https://github.com/Azure/azure-sdk-for-python/blob/main/doc/dev/packaging.md

PACKAGE_NAME = "azure-template"
PACKAGE_PPRINT_NAME = "Template Package"

# a-b-c => a/b/c
package_folder_path = PACKAGE_NAME.replace("-", "/")
# a-b-c => a.b.c
namespace_name = PACKAGE_NAME.replace("-", ".")

# Version extraction inspired from 'requests'
with open(os.path.join(package_folder_path, "_version.py"), "r") as fd:
    version = re.search(r'^VERSION\s*=\s*[\'"]([^\'"]*)[\'"]', fd.read(), re.MULTILINE).group(1)
if not version:
    raise RuntimeError("Cannot find version information")

with open("README.md", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name=PACKAGE_NAME,
    version=version,
    description="Microsoft Azure {} Client Library for Python".format(PACKAGE_PPRINT_NAME),
    # ensure that these are updated to reflect the package owners' information
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Azure/azure-sdk-for-python",
    keywords="azure, azure sdk",  # update with search keywords relevant to the azure service / product
    author="Microsoft Corporation",
    author_email="azuresdkengsysadmins@microsoft.com",
    license="MIT License",
    # ensure that the development status reflects the status of your package
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: MIT License",
    ],
    packages=find_packages(
        exclude=[
            "tests",
            # Exclude packages that will be covered by PEP420 or nspkg
            # This means any folder structure that only consists of a __init__.py.
            # For example, for storage, this would mean adding 'azure.storage'
            # in addition to the default 'azure' that is seen here.
            "azure",
        ]
    ),
    include_package_data=True,
    package_data={
        "azure.template": ["py.typed"],
    },
    install_requires=[
        "azure-core<2.0.0,>=1.23.0",
    ],
    python_requires=">=3.7",
    project_urls={
        "Bug Reports": "https://github.com/Azure/azure-sdk-for-python/issues",
        "Source": "https://github.com/Azure/azure-sdk-for-python",
    },
)
